@@ -98,8 +98,7 @@ WHERE  created > SYSDATE - 7;''')
     def do_longops(self,args):
         '''Runs query_longops defined above, to display long running operations (full scans, etc)'''
         self.onecmd(self.query_longops)
-
-    do_get = Cmd.do__load
+        
     def do_load(self,args):
         '''Runs query_load10g defined above, to display OS load on cluster nodes (10gRAC)
 Do not confuse with `GET myfile.sql` and `@myfile.sql`,
@@ -123,7 +122,10 @@ which get and run SQL scripts from disk.'''
         f.close()
 
     def do_tselect(self, arg):  
-        '''executes a query and prints the result in trasposed form. Useful when querying tables with many columns'''  
+        '''
+        Executes a query and prints the result in trasposed form;
+        equivalent to terminating query with `\\t` instead of `;`.
+        Useful when querying tables with many columns and few rows.'''  
         self.do_select(self.parsed(arg, terminator='\\t'))
 
     def do_sql(self,args):
@@ -193,7 +195,7 @@ def run():
                 pass
             my.do_connect(connectstring)
         for arg in sys.argv[1:]:
-            if my.onecmd(arg) == my._STOP_AND_EXIT:
+            if my.onecmd(arg + '\n') == my._STOP_AND_EXIT:
                 return
     except IndexError:
         pass
